@@ -1,7 +1,7 @@
 package Dist::Zilla::PluginBundle::Author::PERLANCAR;
 
-our $DATE = '2016-01-19'; # DATE
-our $VERSION = '0.46'; # VERSION
+our $DATE = '2016-02-20'; # DATE
+our $VERSION = '0.47'; # VERSION
 
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -41,7 +41,7 @@ sub configure {
         'Test::Compile',
         'Test::Rinci',
         'EnsureSQLSchemaVersionedTest',
-        ['Acme::CPANLists::Blacklist' => {module_list=>[q[PERLANCAR::Modules I'm avoiding]]}],
+        ['Acme::CPANLists::Blacklist' => {module_list=>[q[PERLANCAR::Avoided::Modules I'm currently avoiding]]}],
         'Prereqs::EnsureVersion',
     );
 }
@@ -63,7 +63,7 @@ Dist::Zilla::PluginBundle::Author::PERLANCAR - Dist::Zilla like PERLANCAR when y
 
 =head1 VERSION
 
-This document describes version 0.46 of Dist::Zilla::PluginBundle::Author::PERLANCAR (from Perl distribution Dist-Zilla-PluginBundle-Author-PERLANCAR), released on 2016-01-19.
+This document describes version 0.47 of Dist::Zilla::PluginBundle::Author::PERLANCAR (from Perl distribution Dist-Zilla-PluginBundle-Author-PERLANCAR), released on 2016-02-20.
 
 =head1 SYNOPSIS
 
